@@ -34,7 +34,6 @@
 #include "orbitcpp/idl-compiler/types/IDLAttribAccessor.h"
 
 #include <iostream>
-#include <sstream>
 
 
 // IDLPassSkels --------------------------------------------------------------
@@ -404,21 +403,23 @@ IDLPassSkels::defineEPV (IDLInterface &iface,
 		IDLElement *item = 0;
     
 		switch (IDL_NODE_TYPE(IDL_LIST(body_list).data)) {
-		case IDLN_ATTR_DCL:
+		case IDLN_ATTR_DCL: {
 			item = of.getItem(IDL_LIST(body_list).data);
+			IDLAttribute *attr = dynamic_cast<IDLAttribute*>(item);
+			g_assert(attr != 0);
 			m_module << mod_indent << iface.get_cpp_poa_typename ()
-				 << "::_skel__get_" << item->get_cpp_identifier ()
+				 << "::" << IDLAttribGetter(*attr).skel_get_cpp_methodname ()
 				 << ',' << endl;
 			{
-				IDLAttribute *attr = dynamic_cast<IDLAttribute*>(item);
 				if (!attr->isReadOnly ())
 				{
 					m_module << mod_indent << iface.get_cpp_poa_typename ()
-						 << "::_skel__set_" << item->get_cpp_identifier ()
+						 << "::" << IDLAttribSetter(*attr).skel_get_cpp_methodname ()
 						 << ',' << endl;
 				}
 			}
-			break;
+		} break;
+			
 		case IDLN_OP_DCL:
 			item = of.getItem(IDL_LIST(body_list).data);
 			m_module << mod_indent << iface.get_cpp_poa_typename ()
@@ -489,20 +490,19 @@ IDLPassSkels::doInterface (IDLInterface &iface)
 void 
 IDLPassSkels::doInterfaceDerive(IDLInterface &iface) {
 	// class header
-	m_header << indent << "class " << iface.get_cpp_poa_identifier () << ": "
-		 << "public " << iface.get_cpp_typename ();
+	m_header << indent << "class " << iface.get_cpp_poa_identifier () << ": ";
 
 	if (iface.m_bases.size ())
 	{
 		for (IDLInterface::BaseList::const_iterator i = iface.m_bases.begin ();
 		     i != iface.m_bases.end (); i++)
 		{
-			m_header << ", public virtual " << (*i)->get_cpp_poa_identifier ();
+			m_header << "public virtual " << (*i)->get_cpp_poa_typename () << ", ";
 		}
-	} else {
-		m_header << ", public virtual "
-			 << IDL_POA_NS "::ServantBase" << endl;
 	}
+
+	m_header << "public virtual "
+		 << IDL_POA_NS "::ServantBase" << endl;
 	
 	m_header << indent++ << "{" << endl;
 
@@ -580,17 +580,10 @@ IDLPassSkels::doInterfaceDerive(IDLInterface &iface) {
 		 << mod_indent++ << "{" << endl;
 
 	m_module << mod_indent << "PortableServer::POA_var rootPOA = _default_POA ();" << endl << endl;
-	m_module << mod_indent << "static bool activated = false;" << endl;
-	m_module << mod_indent << "PortableServer::ObjectId_var oid = "
-		 << "activated ? rootPOA->servant_to_id (this) : rootPOA->activate_object (this);" << endl;
-	m_module << mod_indent << "activated = true;" << endl << endl;
 	
-	m_module << mod_indent << "CORBA::Object_ptr object = rootPOA->id_to_reference (oid);" << endl;
-	m_module << mod_indent << iface.get_cpp_typename_ptr () << " pDerived = "
+	m_module << mod_indent << "CORBA::Object_var object = rootPOA->servant_to_reference (this);" << endl;
+	m_module << mod_indent << "return "
 		 << stub_name << "::_orbitcpp_wrap (object->_orbitcpp_cobj (), true);" << endl;
-	m_module << mod_indent << "CORBA::release (object);" << endl
-		 << mod_indent << "object = 0;" << endl;
-	m_module << mod_indent << "return pDerived;" << endl;
 	m_module << --mod_indent << "}" << endl << endl;
 
 	
